@@ -1,10 +1,14 @@
+# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin,unused-import
 """
 Main interface for route53 service client paginators.
 
 Usage::
 
+    ```python
     import boto3
-    from mypy_boto3.route53 import (
+
+    from mypy_boto3_route53 import Route53Client
+    from mypy_boto3_route53.paginator import (
         ListHealthChecksPaginator,
         ListHostedZonesPaginator,
         ListQueryLoggingConfigsPaginator,
@@ -19,10 +23,12 @@ Usage::
     list_query_logging_configs_paginator: ListQueryLoggingConfigsPaginator = client.get_paginator("list_query_logging_configs")
     list_resource_record_sets_paginator: ListResourceRecordSetsPaginator = client.get_paginator("list_resource_record_sets")
     list_vpc_association_authorizations_paginator: ListVPCAssociationAuthorizationsPaginator = client.get_paginator("list_vpc_association_authorizations")
+    ```
 """
-# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
-from typing import Iterator, TYPE_CHECKING
+from typing import Iterator
+
 from botocore.paginate import Paginator as Boto3Paginator
+
 from mypy_boto3_route53.type_defs import (
     ListHealthChecksResponseTypeDef,
     ListHostedZonesResponseTypeDef,
@@ -32,7 +38,6 @@ from mypy_boto3_route53.type_defs import (
     PaginatorConfigTypeDef,
 )
 
-
 __all__ = (
     "ListHealthChecksPaginator",
     "ListHostedZonesPaginator",
@@ -44,59 +49,59 @@ __all__ = (
 
 class ListHealthChecksPaginator(Boto3Paginator):
     """
-    [Paginator.ListHealthChecks documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.49/reference/services/route53.html#Route53.Paginator.ListHealthChecks)
+    [Paginator.ListHealthChecks documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.2/reference/services/route53.html#Route53.Paginator.ListHealthChecks)
     """
 
     def paginate(
         self, PaginationConfig: PaginatorConfigTypeDef = None
     ) -> Iterator[ListHealthChecksResponseTypeDef]:
         """
-        [ListHealthChecks.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.49/reference/services/route53.html#Route53.Paginator.ListHealthChecks.paginate)
+        [ListHealthChecks.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.2/reference/services/route53.html#Route53.Paginator.ListHealthChecks.paginate)
         """
 
 
 class ListHostedZonesPaginator(Boto3Paginator):
     """
-    [Paginator.ListHostedZones documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.49/reference/services/route53.html#Route53.Paginator.ListHostedZones)
+    [Paginator.ListHostedZones documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.2/reference/services/route53.html#Route53.Paginator.ListHostedZones)
     """
 
     def paginate(
         self, DelegationSetId: str = None, PaginationConfig: PaginatorConfigTypeDef = None
     ) -> Iterator[ListHostedZonesResponseTypeDef]:
         """
-        [ListHostedZones.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.49/reference/services/route53.html#Route53.Paginator.ListHostedZones.paginate)
+        [ListHostedZones.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.2/reference/services/route53.html#Route53.Paginator.ListHostedZones.paginate)
         """
 
 
 class ListQueryLoggingConfigsPaginator(Boto3Paginator):
     """
-    [Paginator.ListQueryLoggingConfigs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.49/reference/services/route53.html#Route53.Paginator.ListQueryLoggingConfigs)
+    [Paginator.ListQueryLoggingConfigs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.2/reference/services/route53.html#Route53.Paginator.ListQueryLoggingConfigs)
     """
 
     def paginate(
         self, HostedZoneId: str = None, PaginationConfig: PaginatorConfigTypeDef = None
     ) -> Iterator[ListQueryLoggingConfigsResponseTypeDef]:
         """
-        [ListQueryLoggingConfigs.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.49/reference/services/route53.html#Route53.Paginator.ListQueryLoggingConfigs.paginate)
+        [ListQueryLoggingConfigs.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.2/reference/services/route53.html#Route53.Paginator.ListQueryLoggingConfigs.paginate)
         """
 
 
 class ListResourceRecordSetsPaginator(Boto3Paginator):
     """
-    [Paginator.ListResourceRecordSets documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.49/reference/services/route53.html#Route53.Paginator.ListResourceRecordSets)
+    [Paginator.ListResourceRecordSets documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.2/reference/services/route53.html#Route53.Paginator.ListResourceRecordSets)
     """
 
     def paginate(
         self, HostedZoneId: str, PaginationConfig: PaginatorConfigTypeDef = None
     ) -> Iterator[ListResourceRecordSetsResponseTypeDef]:
         """
-        [ListResourceRecordSets.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.49/reference/services/route53.html#Route53.Paginator.ListResourceRecordSets.paginate)
+        [ListResourceRecordSets.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.2/reference/services/route53.html#Route53.Paginator.ListResourceRecordSets.paginate)
         """
 
 
 class ListVPCAssociationAuthorizationsPaginator(Boto3Paginator):
     """
-    [Paginator.ListVPCAssociationAuthorizations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.49/reference/services/route53.html#Route53.Paginator.ListVPCAssociationAuthorizations)
+    [Paginator.ListVPCAssociationAuthorizations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.2/reference/services/route53.html#Route53.Paginator.ListVPCAssociationAuthorizations)
     """
 
     def paginate(
@@ -106,5 +111,5 @@ class ListVPCAssociationAuthorizationsPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[ListVPCAssociationAuthorizationsResponseTypeDef]:
         """
-        [ListVPCAssociationAuthorizations.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.49/reference/services/route53.html#Route53.Paginator.ListVPCAssociationAuthorizations.paginate)
+        [ListVPCAssociationAuthorizations.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.2/reference/services/route53.html#Route53.Paginator.ListVPCAssociationAuthorizations.paginate)
         """
